@@ -4,6 +4,8 @@
 //     Full Text: https://github.com/fernandezfran/exma/blob/master/LICENSE
 #include "pbc_distances.h"
 
+#include <math.h>
+
 void distance_matrix(const int natoms_c, const int natoms_i, const float *box,
                      const float *x_central, const float *x_interact,
                      float *distrix) {
@@ -23,19 +25,23 @@ void distance_matrix(const int natoms_c, const int natoms_i, const float *box,
     float rij, rij2;
 
     // i'm standing on the central atoms
-    for (int i = 0; i < natoms_c; i++) {
+    for (int i = 0; i < natoms_c; ++i) {
 
         // select the vector position of a particular one
-        for (int k = 0; k < 3; k++) { ri[k] = x_central[k * natoms_c + i]; }
+        for (int k = 0; k < 3; ++k) {
+            ri[k] = x_central[k * natoms_c + i];
+        }
 
         // computes the distance to all interacting atoms
-        for (int j = 0; j < natoms_i; j++) {
+        for (int j = 0; j < natoms_i; ++j) {
             rij2 = 0.0f;
-            for (int k = 0; k < 3; k++) {
+            for (int k = 0; k < 3; ++k) {
                 rj[k] = x_interact[k * natoms_i + j];
                 rij = rj[k] - ri[k];
-                while (rij > 0.5f * box[k]) rij -= box[k];
-                while (rij < -0.5f * box[k]) rij += box[k];
+                while (rij > 0.5f * box[k])
+                    rij -= box[k];
+                while (rij < -0.5f * box[k])
+                    rij += box[k];
                 rij2 += rij * rij;
             }
 
